@@ -71,7 +71,7 @@ def deployModel(api_token, account_name, account_id, model_name, version_name, p
     # TODO: consider doing this AFTER we successfully upload the model
     # TODO: look up model type 
     # TODO: return namespace name when we write it successfully
-    if memoryLimit < 0.0:
+    if memoryLimit < 0.0 and memoryLimit != -999.9:
         print(f"Error. You must provide a memory limit that is greater than 0. You provided {memoryLimit}")
         return(False)
     if(check_string(model_name)==False):
